==> ag.db_2.0.2.tar.gz: ag.db/man/agPMID2PROBE.Rd <==
\name{agPMID2PROBE}
\alias{agPMID2PROBE}
\title{Map between PubMed Identifiers and Manufacturer Identifiers}
\description{
  agPMID2PROBE is an R object that provides mappings between
  PubMed identifiers and manufacturer identifiers.
}
\details{
  Each PubMed identifier is mapped to a named vector of manufacturer identifiers. The
  name represents the PubMed identifier and the vector contains all manufacturer
  identifiers that are represented by that PubMed identifier. The length of the vector
  may be one or longer, depending on how many manufacturer identifiers are
  mapped to a given PubMed identifier.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed identifier. The pubmed function of
  annotate can also be used for the same purpose
  
  Mappings were based on data provided by: Tair ( ftp://ftp.arabidopsis.org/User\_Requests/LocusPublished.08022007.txt ) on 2007-Aug2
  
}

\examples{
    # Convert the object to a list
    xx <- as.list(agPMID2PROBE)
    if(length(xx) > 0){
        # The probe identifiers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && require(annotate)){
            # Gets article information as XML files for a PubMed id
            xmls <- pubmed(names(xx)[1], disp = "data")
            # Views article information using a browser
            pubmed(names(xx)[1], disp = "browser")
        }
    }
}

\keyword{datasets}

==> ag.db_2.2.0.tar.gz: ag.db/man/agPMID2PROBE.Rd <==
\name{agPMID2PROBE}
\alias{agPMID2PROBE}
\title{Map between PubMed Identifiers and Manufacturer Identifiers}
\description{
  agPMID2PROBE is an R object that provides mappings between
  PubMed identifiers and manufacturer identifiers.
}
\details{
  Each PubMed identifier is mapped to a named vector of manufacturer identifiers. The
  name represents the PubMed identifier and the vector contains all manufacturer
  identifiers that are represented by that PubMed identifier. The length of the vector
  may be one or longer, depending on how many manufacturer identifiers are
  mapped to a given PubMed identifier.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed identifier. The pubmed function of
  annotate can also be used for the same purpose
  
  Mappings were based on data provided by: Tair ( ftp://ftp.arabidopsis.org/User\_Requests/LocusPublished.10042007.txt ) on 2007-Oct04
  
}

\examples{
    # Convert the object to a list
    xx <- as.list(agPMID2PROBE)
    if(length(xx) > 0){
        # The probe identifiers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && require(annotate)){
            # Gets article information as XML files for a PubMed id
            xmls <- pubmed(names(xx)[1], disp = "data")
            # Views article information using a browser
            pubmed(names(xx)[1], disp = "browser")
        }
    }
}

\keyword{datasets}
